@@ -148,8 +148,7 @@ class image_augmentation(object):
                
         ################
         if self.pattern_shift:
-            #TODO: Pattern shift for cbed 
-            #09/22/2021 - Joydeep Munshi
+            #Added on 09/22/2021 - Joydeep Munshi
             input_noise = self.pattern_shift_ar(input_noise)
         else:
             self.xhsift = 0
@@ -185,9 +184,12 @@ class image_augmentation(object):
     
     @tf.function
     def shot_noise(self, inputs: aug_utils.TensorLike):
-        #input_shape = inputs.shape
-        image_scale = self.scale_image(inputs)
-        image_noise = tf.random.poisson(shape = [], lam = tf.maximum(image_scale,0) * self.counts_per_pixel)/float(self.counts_per_pixel)
+        """
+        Apply Shot noise
+        """
+        image = tf.convert_to_tensor(inputs)
+        #image_scale = self.scale_image(inputs)
+        image_noise = tf.random.poisson(shape = [], lam = tf.maximum(image,0) * self.counts_per_pixel)/float(self.counts_per_pixel)
         
         return image_noise
     
